---

# Elite SDK For Python

> ### 明天比今天更简单一点
>
> ### Always Easier Then Before


elirobot是一个Python库,包含了艾利特机器人的EC系列机器人的SDK封装，用户即开即用，非常方便

# Overview

## Installation

```bash
pip install elirobots
# or
pip3 install elirobots
```

## Docs

[elirobots docs](https://eliterobot.readthedocs.io/zh_CN/latest/)

## Features

- 从复杂的底层通讯建立到开箱即用，只需要一条命令和几行代码
- 面向对象设计，从而可以更轻松的控制多台机器人
- 完善的日志输出，可以更轻松的debug
- 将机器人的固有信息作为类的属性使用
- 更简洁的接口设计，使您可以更快速的编写逻辑代码
- 数据监控端口，也只是两行代码就可以看到所有的监控信息

# ChangeLog

## 20220730

- movj和movl接口默认阻塞执行
- 添加发送和接受消息的flag，便于用户查看实际进行通讯的报文内容
- 添加圆弧移动指令
- 

## 20220518

- 规范var接口
- 文档持续更新中

## 20220513

- 发布v0.0.1
- 文档持续更新中



# Feedback

如果你发现了任何错误，请联系我们！！！

If you find any errors, you can contact us by Github！！！

github:

```
https://github.com/JunJie-zhang-o/eliterobot.git
```

email:

```
tech@elibot.cn
```

